@@ -18,30 +18,30 @@ def _assert_square_cholesky(a):
     assert_square(a, "Can only take the Cholesky decomposition of square matrices.")
 
 
-@B.dispatch(Zero)
-def cholesky(a):
+@B.dispatch
+def cholesky(a: Zero):
     _assert_square_cholesky(a)
     return a
 
 
-@B.dispatch(Dense)
-def cholesky(a):
+@B.dispatch
+def cholesky(a: Dense):
     _assert_square_cholesky(a)
     if a.cholesky is None:
         a.cholesky = LowerTriangular(B.cholesky(B.reg(a.mat)))
     return a.cholesky
 
 
-@B.dispatch(Diagonal)
-def cholesky(a):
+@B.dispatch
+def cholesky(a: Diagonal):
     _assert_square_cholesky(a)
     if a.cholesky is None:
         a.cholesky = Diagonal(B.sqrt(a.diag))
     return a.cholesky
 
 
-@B.dispatch(Constant)
-def cholesky(a):
+@B.dispatch
+def cholesky(a: Constant):
     _assert_square_cholesky(a)
     if a.cholesky is None:
         chol_const = B.divide(B.sqrt(a.const), B.sqrt(a.cols))
@@ -49,16 +49,16 @@ def cholesky(a):
     return a.cholesky
 
 
-@B.dispatch(LowRank)
-def cholesky(a):
+@B.dispatch
+def cholesky(a: LowRank):
     _assert_square_cholesky(a)
     if a.cholesky is None:
         a.cholesky = B.matmul(a.left, B.cholesky(a.middle))
     return a.cholesky
 
 
-@B.dispatch(Woodbury)
-def cholesky(a):
+@B.dispatch
+def cholesky(a: Woodbury):
     if a.cholesky is None:
         warn_upmodule(
             f"Converting {a} to dense to compute its Cholesky decomposition.",
@@ -68,8 +68,8 @@ def cholesky(a):
     return a.cholesky
 
 
-@B.dispatch(Kronecker)
-def cholesky(a):
+@B.dispatch
+def cholesky(a: Kronecker):
     if a.cholesky is None:
         a.cholesky = Kronecker(B.cholesky(a.left), B.cholesky(a.right))
-    return a.cholesky
+    return a.cholesky
\ No newline at end of file
