@@ -1,3 +1,5 @@
+from typing import Union
+
 import lab as B
 
 from ..constant import Zero, Constant
@@ -11,7 +13,7 @@ from ..kronecker import Kronecker
 __all__ = []
 
 
-@B.dispatch(object)
+@B.dispatch
 def dense(a):
     """Convert a (structured) matrix to a dense, numeric matrix.
 
@@ -27,48 +29,48 @@ def dense(a):
 B.dense = dense
 
 
-@B.dispatch(Zero)
-def dense(a):
+@B.dispatch
+def dense(a: Zero):
     if a.dense is None:
         a.dense = B.zeros(a.dtype, a.rows, a.cols)
     return a.dense
 
 
-@B.dispatch({Dense, LowerTriangular, UpperTriangular})
-def dense(a):
+@B.dispatch
+def dense(a: Union[Dense, LowerTriangular, UpperTriangular]):
     return a.mat
 
 
-@B.dispatch(Diagonal)
-def dense(a):
+@B.dispatch
+def dense(a: Diagonal):
     if a.dense is None:
         a.dense = B.diag(a.diag)
     return a.dense
 
 
-@B.dispatch(Constant)
-def dense(a):
+@B.dispatch
+def dense(a: Constant):
     if a.dense is None:
         a.dense = a.const * B.ones(B.dtype(a.const), a.rows, a.cols)
     return a.dense
 
 
-@B.dispatch(LowRank)
-def dense(a):
+@B.dispatch
+def dense(a: LowRank):
     if a.dense is None:
         a.dense = B.dense(B.mm(a.left, a.middle, a.right, tr_c=True))
     return a.dense
 
 
-@B.dispatch(Woodbury)
-def dense(a):
+@B.dispatch
+def dense(a: Woodbury):
     if a.dense is None:
         a.dense = B.dense(a.diag) + B.dense(a.lr)
     return a.dense
 
 
-@B.dispatch(Kronecker)
-def dense(a):
+@B.dispatch
+def dense(a: Kronecker):
     if a.dense is None:
         a.dense = B.kron(B.dense(a.left), B.dense(a.right))
     return a.dense
