@@ -5,6 +5,6 @@ from ..matrix import AbstractMatrix
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix)
-def to_numpy(a):
-    return B.to_numpy(B.dense(a))
+@B.dispatch
+def to_numpy(a: AbstractMatrix):
+    return B.to_numpy(B.dense(a))
\ No newline at end of file
